// Shim for scripts/domWidget.ts
export const isDOMWidget = window.comfyAPI.domWidget.isDOMWidget;
export const isComponentWidget = window.comfyAPI.domWidget.isComponentWidget;
export const DOMWidgetImpl = window.comfyAPI.domWidget.DOMWidgetImpl;
export const ComponentWidgetImpl = window.comfyAPI.domWidget.ComponentWidgetImpl;
export const addWidget = window.comfyAPI.domWidget.addWidget;
export const pruneWidgets = window.comfyAPI.domWidget.pruneWidgets;
