
.spinner[data-v-fd51e330] {
  width: 50px;
  height: 50px;
  border: 4px solid #f3f3f3;
  border-top: 4px solid #3498db;
  border-radius: 50%;
  animation: spin-fd51e330 1s linear infinite;
}
@keyframes spin-fd51e330 {
0% {
    transform: rotate(0deg);
}
100% {
    transform: rotate(360deg);
}
}

.recording-button-blink[data-v-ad2a47fe] {
  animation: blink-ad2a47fe 1s infinite;
}
@keyframes blink-ad2a47fe {
0%,
  100% {
    opacity: 1;
}
50% {
    opacity: 0.5;
}
}
